# pypyroject.toml

The pyproject.toml is the main configuration file used for the Python project.
It contains configurations for building, linting, testing, and publishing the Python package.

The pyproject.toml replaces the "setup.py" package. When using 'flit' or 'poetry', only the pyproject.toml is required.
This project currently uses 'flit', but in the future may also include a 'poetry' example. Both are considered viable options.

When using setuptools, and setup.cfg is still required.
